=========
Changelog
=========

1.0.4
-----

- Exempt specific URLs #33

1.0.3
-----

- Command bug fixes
- Added date/time to unicode for models.

1.0.2
-----

- Add downtime up/down commands

1.0.1
-----
- Templates were not bundled correctly in 1.0.0

1.0.0
-----
- Python 2/3 Support. Django 1.8 support

0.3.3
-----
- Change status code to 503 #13

0.3.2
-----
- Minor changes to fix deprecation warnings in Django 1.7.

0.3.1
-----

0.3
---

0.2
---

0.1
---
